@@ -115,40 +115,39 @@ class TestBaremetalNode(base.IronicTestCase):
                              'validate']),
                  json=validate_return),
         ])
-        self.op_cloud.validate_node(self.fake_baremetal_node['uuid'])
-
+        validate_resp = self.op_cloud.validate_node(
+            self.fake_baremetal_node['uuid'])
+        self.assertDictEqual(validate_return, validate_resp)
         self.assert_calls()
 
-    # FIXME(TheJulia): So, this doesn't presently fail, but should fail.
-    # Placing the test here, so we can sort out the issue in the actual
-    # method later.
-    # def test_validate_node_raises_exception(self):
-    #    validate_return = {
-    #        'deploy': {
-    #            'result': False,
-    #            'reason': 'error!',
-    #        },
-    #        'power': {
-    #            'result': False,
-    #            'reason': 'meow!',
-    #        },
-    #        'foo': {
-    #            'result': True
-    #        }}
-    #    self.register_uris([
-    #        dict(method='GET',
-    #             uri=self.get_mock_url(
-    #                 resource='nodes',
-    #                 append=[self.fake_baremetal_node['uuid'],
-    #                         'validate']),
-    #             json=validate_return),
-    #    ])
-    #    self.assertRaises(
-    #        Exception,
-    #        self.op_cloud.validate_node,
-    #        self.fake_baremetal_node['uuid'])
-    #
-    #    self.assert_calls()
+    def test_validate_node_raises_exception(self):
+        validate_return = {
+            'deploy': {
+                'result': False,
+                'reason': 'error!',
+            },
+            'power': {
+                'result': False,
+                'reason': 'meow!',
+            },
+            'foo': {
+                'result': True
+            }}
+        self.register_uris([
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     resource='nodes',
+                     append=[self.fake_baremetal_node['uuid'],
+                             'validate']),
+                 json=validate_return),
+        ])
+        self.assertRaisesRegexp(
+            exc.OpenStackCloudException,
+            '^ironic node .* failed to validate.*',
+            self.op_cloud.validate_node,
+            self.fake_baremetal_node['uuid'])
+
+        self.assert_calls()
 
     def test_patch_machine(self):
         test_patch = [{
@@ -858,6 +857,46 @@ class TestBaremetalNode(base.IronicTestCase):
         self.assertEqual(available_node, return_value)
         self.assert_calls()
 
+    def test_node_set_provision_state_bad_request(self):
+        self.fake_baremetal_node['provision_state'] = 'enroll'
+        self.register_uris([
+            dict(
+                method='PUT',
+                status_code=400,
+                json={'error': "{\"faultstring\": \"invalid state\"}"},
+                uri=self.get_mock_url(
+                    resource='nodes',
+                    append=[self.fake_baremetal_node['uuid'],
+                            'states', 'provision'])),
+        ])
+        self.assertRaisesRegexp(
+            exc.OpenStackCloudException,
+            '^Baremetal .* to dummy.*/states/provision invalid state$',
+            self.op_cloud.node_set_provision_state,
+            self.fake_baremetal_node['uuid'],
+            'dummy')
+        self.assert_calls()
+
+    def test_node_set_provision_state_bad_request_bad_json(self):
+        self.fake_baremetal_node['provision_state'] = 'enroll'
+        self.register_uris([
+            dict(
+                method='PUT',
+                status_code=400,
+                json={'error': 'invalid json'},
+                uri=self.get_mock_url(
+                    resource='nodes',
+                    append=[self.fake_baremetal_node['uuid'],
+                            'states', 'provision'])),
+        ])
+        self.assertRaisesRegexp(
+            exc.OpenStackCloudException,
+            '^Baremetal .* to dummy.*/states/provision$',
+            self.op_cloud.node_set_provision_state,
+            self.fake_baremetal_node['uuid'],
+            'dummy')
+        self.assert_calls()
+
     def test_wait_for_baremetal_node_lock_locked(self):
         self.fake_baremetal_node['reservation'] = 'conductor0'
         unlocked_node = self.fake_baremetal_node.copy()
